.. _api:

API
===
    .. currentmodule:: flaat


    .. autoclass:: Flaat
       :members: group_required, aarc_g002_group_required, login_required,
                 set_trusted_OP, set_trusted_OP_list, set_trusted_OP_file, set_OP_hint,
                 set_verbosity, set_web_framework

